@@ -133,18 +133,24 @@ class DaikinBRP069(Appliance):
     async def _update_settings(self, settings):
         """Update settings to set on Daikin device."""
         # start with current values
-        current_val = await self._get_resource('aircon/get_control_info')
+        resource = 'aircon/get_control_info'
+        current_val = await self._get_resource(resource)
 
         # Merge current_val with mapped settings
-        self.values.update(current_val)
-        self.values.update({k: self.human_to_daikin(k, v) for k, v in settings.items()})
+        self.values.update_by_resource(resource, current_val)
+        self.values.update_by_resource(
+            resource, {k: self.human_to_daikin(k, v) for k, v in settings.items()}
+        )
 
         # we are using an extra mode "off" to power off the unit
         if settings.get('mode', '') == 'off':
             self.values['pow'] = '0'
             # some units are picky with the off mode
             self.values['mode'] = current_val['mode']
-        else:
+
+        # if changing the mode to something other than off assume the unit should be
+        # powered on OR if the request is empty power on
+        elif 'mode' in settings or not settings:
             self.values['pow'] = '1'
 
         # Use settings for respecitve mode (dh and dt)
@@ -207,7 +213,7 @@ class DaikinBRP069(Appliance):
             # Update the adv value from the response
             self.values.update(await self._get_resource(query_h))
 
-    async def set_zone(self, zone_id, status):
+    async def set_zone(self, zone_id, key, value):
         """Set zone status."""
 
     async def auto_set_clock(self):
