@@ -169,10 +169,12 @@ class DaikinSkyFi(Appliance):
             if v != f'Zone {i+1}'
         ]
 
-    async def set_zone(self, zone_id, status):
+    async def set_zone(self, zone_id, key, value):
         """Set zone status."""
+        if key != 'zone_onoff':
+            return
         zone_id += 1
-        query = f'setzone.cgi?pass={{}}&z={zone_id}&s={status}'
+        query = f'setzone.cgi?pass={{}}&z={zone_id}&s={value}'
         _LOGGER.debug("Set zone: %s", query)
         current_state = await self._get_resource(query)
         self.values.update(current_state)
